@@ -3,6 +3,8 @@ from grpc import Channel
 from nibiru.proto.perp.v1 import query_pb2 as perp_type
 from nibiru.proto.perp.v1 import query_pb2_grpc as perp_query
 
+from .util import deserialize
+
 
 class Perp:
     """
@@ -14,11 +16,11 @@ class Perp:
 
     def params(self):
         req = perp_type.QueryParamsRequest()
-        return self.api.Params(req)
+        return deserialize(self.api.Params(req))
 
     def trader_position(self, token_pair: str, trader: str):
         req = perp_type.QueryTraderPositionRequest(
             token_pair=token_pair,
             trader=trader,
         )
-        return self.api.TraderPosition(req)
+        return deserialize(self.api.TraderPosition(req))
